
gaussdecomp
===========

Gaussian Decomposition routines.


Authors
-------

- **David Nidever** (Montana State University)

  
Installation
------------

To install the latest version::

    pip install git+https://github.com/dnidever/gaussdecomp

    
Documentation
-------------

.. image:: https://readthedocs.org/projects/gaussdecomp/badge/?version=latest
        :target: http://theborg.readthedocs.io/

See `the documentation <http://gaussdecomp.readthedocs.io>`_ for information on how
to install and use `gaussdecomp`.

License
-------

.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/dnidever/gaussdecomp/blob/main/LICENSE
